@@ -20,7 +20,11 @@ You should have received a copy of the GNU General Public License
 along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from apav.analysis.massspectrum import LocalBkgCorrectedMassSpectrum, CorrelationHistogram, \
-    NoiseCorrectedMassSpectrum, RangedMassSpectrum
+from apav.analysis.massspectrum import (
+    LocalBkgCorrectedMassSpectrum,
+    CorrelationHistogram,
+    NoiseCorrectedMassSpectrum,
+    RangedMassSpectrum,
+)
 from apav.analysis.background import Background, BackgroundCollection
-from apav.analysis.spatial import DensityHistogram
+from apav.analysis.spatial import DensityHistogram, RangedGrid
