@@ -20,7 +20,9 @@ You should have received a copy of the GNU General Public License
 along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from apav.utils.hinting import *
+from typing import Sequence, Tuple, List, Dict, Any, Union, Type, Optional, TYPE_CHECKING
+from numbers import Real, Number
+from lmfit import Model
 
 from copy import deepcopy
 
@@ -31,6 +33,7 @@ from apav.analysis import models
 import apav.utils.constants
 
 import numpy as n
+from numpy import ndarray
 from lmfit.minimizer import MinimizerResult
 from lmfit.models import PowerLawModel
 
