@@ -21,9 +21,12 @@ along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from collections import defaultdict, OrderedDict
-from warnings import warn
 from copy import deepcopy
 
+from typing import Sequence, Tuple, List, Dict, Any, Union, Type, Optional, TYPE_CHECKING
+from numbers import Real, Number
+
+from numpy import ndarray
 import numpy as n
 from tabulate import tabulate
 from lmfit.models import PowerLawModel
@@ -35,7 +38,6 @@ from apav.core.roi import DummyRoiHistogram, Roi
 from apav.visualization import plotting
 from apav.analysis.base import AnalysisBase
 from apav.utils import validate
-from apav.utils.hinting import *
 from apav.analysis.background import BackgroundCollection, Background
 from apav.utils.logging import log
 
