@@ -25,7 +25,7 @@ from numpy.polynomial import Polynomial
 from lmfit.models import Model, update_param_vals
 from lmfit.models import ExponentialGaussianModel as _EXPGauss
 
-from apav.utils.hinting import *
+from numpy import ndarray
 
 
 class ExponentialGaussianModel(_EXPGauss):
