@@ -19,6 +19,9 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
+from typing import Sequence, Tuple, List, Dict, Any, Union, Type, Optional, TYPE_CHECKING
+from numbers import Real, Number
+from numpy import ndarray
 
 import periodictable as pt
 from periodictable import elements as el
@@ -33,7 +36,6 @@ from collections import defaultdict
 import re
 from copy import deepcopy
 
-from apav.utils.hinting import *
 from apav.utils import validate
 
 
