@@ -20,6 +20,10 @@ You should have received a copy of the GNU General Public License
 along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+from typing import Sequence, Tuple, List, Dict, Any, Union, Type, Optional, TYPE_CHECKING
+from numbers import Real, Number
+from apav.core.isotopic import Element
+
 from collections import OrderedDict
 from configparser import ConfigParser
 import copy
@@ -28,7 +32,6 @@ from tabulate import tabulate
 import numpy as n
 
 from apav.utils import helpers, validate
-from apav.utils.hinting import *
 import apav as ap
 from apav.utils.logging import log
 
