@@ -27,6 +27,10 @@ import struct
 from enum import Enum
 from warnings import warn
 
+from typing import Sequence, Tuple, List, Dict, Any, Union, Type, Optional, TYPE_CHECKING
+from numbers import Real, Number
+from numpy import ndarray
+
 import numpy as n
 import numpy.linalg as la
 
@@ -35,7 +39,6 @@ from apav.utils.helpers import unique_vals, minmax, array2native_byteorder
 from apav.core.multipleevent import get_mass_indices
 from apav.utils.validate import NoMultiEventError, NoDetectorInfoError, NoTOFError
 from apav.core.histogram import histogram1d
-from apav.utils.hinting import *
 from apav.visualization import plotting
 from apav.utils.logging import log
 
@@ -96,7 +99,7 @@ class Roi:
 
         >>> pos_data = Roi.from_pos("path_to_pos_file.pos")  # load a pos file
         >>> epos_data = Roi.from_epos("path_to_epos_file.epos")  # load a epos file
-        >>> ato_data = Roi.from_ato("path_to_ato_file.ato")  # load a ato file
+        >>> ato_data = Roi.from_ato("path_to_ato_file.ato")  # load an ato file
 
         :param xyz: xyz atom coordinates
         :param mass: Mass to charge ratios
