@@ -24,7 +24,7 @@ from typing import TYPE_CHECKING
 
 import numpy as n
 
-from apav.qt import *
+from apav.qt import QDoubleSpinBox, pyqtSignal, QComboBox
 
 if TYPE_CHECKING:
     from apav import Roi
