@@ -20,25 +20,40 @@ You should have received a copy of the GNU General Public License
 along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from apav.analysis.massspectrum import LocalBkgCorrectedMassSpectrum, RangedMassSpectrum, NoiseCorrectedMassSpectrum
+
 import os
 
 import numpy as n
 import pyqtgraph as pg
-from copy import copy
 
-# from apav.vtkall import *
-from apav.qt import *
+from apav.qt import (
+    QWidget,
+    QVBoxLayout,
+    QHBoxLayout,
+    QLabel,
+    QDoubleSpinBox,
+    Qt,
+    QCheckBox,
+    QFileDialog,
+    QDockWidget,
+    QSizePolicy,
+    QLineEdit,
+    QBrush,
+    QColor,
+    QFormLayout,
+    QGroupBox,
+)
+
 from apav.visualization.base import BaseVisualization
 from apav.qtwidgets.massrangewidget import QMassRangeWidget
 from apav.core import histogram
 from apav.utils.helpers import modifying
 import apav.qtwidgets.controls as controls
 
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from apav.analysis.massspectrum import LocalBkgCorrectedMassSpectrum, RangedMassSpectrum, NoiseCorrectedMassSpectrum
-
 pg.setConfigOption("foreground", "k")
 pg.setConfigOption("background", "w")
 pg.setConfigOption("antialias", True)
@@ -622,17 +637,17 @@ class CorrelationHistogramPlot(BaseVisualization):
             return
 
         if corr_hist is not None:
-            with modifying(self.ref_data) as ref_data:
+            with modifying(self.ref_data) as data_mod:
                 multiplicity = self.multiplicity.formattedValue()
 
-                ref_data.multiplicity = multiplicity
-                ref_data.extents = (
+                data_mod.multiplicity = multiplicity
+                data_mod.extents = (
                     (self.lower1.value(), self.upper1.value()),
                     (self.lower2.value(), self.upper2.value()),
                 )
-                ref_data.flip = self.flip.isChecked()
-                ref_data.symmetric = self.symmetric.isChecked()
-                ref_data.bin_width = self.binwidth.value()
+                data_mod.flip = self.flip.isChecked()
+                data_mod.symmetric = self.symmetric.isChecked()
+                data_mod.bin_width = self.binwidth.value()
 
         if self.colorbar:
             self.plot_layout.removeWidget(self.colorbar)
@@ -643,10 +658,10 @@ class CorrelationHistogramPlot(BaseVisualization):
         self.plotter.getPlotItem().showAxis("right")
         self.plotter.getPlotItem().showAxis("top")
 
-        self.data = ref_data.histogram.copy()
-        xrng, yrng = ref_data.extents
+        self.data = self.ref_data.histogram.copy()
+        xrng, yrng = self.ref_data.extents
         non_zero = n.where(self.data > 0)
-        binw = ref_data.bin_width
+        binw = self.ref_data.bin_width
         plot_data = self.data
 
         if self.log_edit.isChecked():
